@@ -1,6 +1,6 @@
 
 /*
- *  $Id: autoopts.c,v 2.40 2002/04/14 22:31:42 bkorb Exp $
+ *  $Id: autoopts.c,v 3.9 2002/05/11 20:23:52 bkorb Exp $
  *
  *  This file contains all of the routines that must be linked into
  *  an executable to use the generated option processing.  The optional
@@ -1372,11 +1372,11 @@ checkConsistency( pOpts )
                     errCt++;
                     fprintf( stderr, zReqFmt, pOD->pz_Name, pN->pz_Name );
                 }
-                
+
                 if (*pMust == NO_EQUIVALENT)
                     break;
             }
-            
+
             if (pCant != (const int*)NULL) for (;;) {
                 tOptDesc*  p = pOpts->pOptDesc + *(pCant++);
                 if (SELECTED_OPT(p)) {
@@ -1463,6 +1463,19 @@ checkConsistency( pOpts )
  *
  *  THESE ROUTINES ARE CALLABLE FROM THE GENERATED OPTION PROCESSING CODE
  */
+/*=--subblock=arg=arg_type,arg_name,arg_desc =*/
+/*=*
+ * library:  opts
+ * header:   your-opts.h
+ *
+ * lib_description:
+ *
+ *  These are the routines that libopts users may call directly from their
+ *  code.  There are several other routines that can be called by code
+ *  generated by the libopts option templates, but they are not to be
+ *  called from any other user code.  The @file{options.h} is fairly clear
+ *  about this, too.
+=*/
 /*=export_func  optionLoadLine
  *
  * what:  process a string for an option name and value
@@ -1470,13 +1483,21 @@ checkConsistency( pOpts )
  * arg:   tOptions*,   pOpts,  program options descriptor
  * arg:   const char*, pzLine, NUL-terminated text
  *
- * doc:   This is a user callable routine for setting options from, for
- *        example, the contents of a file that they read in.
- *        Only one option may appear in the text.  It will be treated
- *        as a normal (non-preset) option.
+ * doc:
+ *
+ * This is a user callable routine for setting options from, for
+ * example, the contents of a file that they read in.
+ * Only one option may appear in the text.  It will be treated
+ * as a normal (non-preset) option.
+ *
+ * When passed a pointer to the option struct and a string, it will
+ * find the option named by the first token on the string and set
+ * the option argument to the remainder of the string.  The caller must
+ * NUL terminate the string.  Any embedded new lines will be included
+ * in the option argument.
  *
  * err:   Invalid options are silently ignored.  Invalid option arguments
- *        will cause a warning to print, but the function will return.
+ *        will cause a warning to print, but the function should return.
 =*/
 void optionLoadLine( pOpts, pzLine )
     tOptions*  pOpts;
@@ -1539,10 +1560,12 @@ void doLoadOpt( pOpts, pOptDesc )
 
 /*=export_func  optionVersion
  *
- * what:     Return the compiled version number
+ * what:     return the compiled AutoOpts version number
  * ret_type: const char*
  * ret_desc: the version string in constant memory
- * doc:      The returned string cannot be modified.
+ * doc:
+ *  Returns the full version string compiled into the library.
+ *  The returned string cannot be modified.
 =*/
 const char*
 optionVersion()
@@ -1557,7 +1580,7 @@ optionVersion()
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*=export_func optionProcess
  *
- * what: the main option processing routine
+ * what: this is the main option processing routine
  *
  * arg:  + tOptions* + pOpts + program options descriptor +
  * arg:  + int       + argc  + program arg count  +
@@ -1565,14 +1588,23 @@ optionVersion()
  * ret_type:  int
  * ret_desc:  the count of the arguments processed
  *
- * doc:  The number of elements processed always includes the program name.
- *       If one of the arguments is "--", then it is counted and the
- *       processing stops.  If an error was encountered and errors are
- *       to be tolerated, then the returned value is the index of the
- *       argument causing the error.
+ * doc:
  *
- * err:  Errors will cause diagnostics to be printed.  'exit(3)' may or
- *       may not be called.  It depends upon whether or not the options
+ * This is the main entry point for processing options.  It is intended
+ * that this procedure be called once at the beginning of the execution of
+ * a program.  Depending on options selected earlier, it is sometimes
+ * necessary to stop and restart option processing, or to select completely
+ * different sets of options.  This can be done easily, but you generally
+ * do not want to do this.
+ *
+ * The number of arguments processed always includes the program name.
+ * If one of the arguments is "--", then it is counted and the
+ * processing stops.  If an error was encountered and errors are
+ * to be tolerated, then the returned value is the index of the
+ * argument causing the error.
+ *
+ * err:  Errors will cause diagnostics to be printed.  @code{exit(3)} may
+ *       or may not be called.  It depends upon whether or not the options
  *       were generated with the "allow-errors" attribute, or if the
  *       ERRSKIP_OPTERR or ERRSTOP_OPTERR macros were invoked.
 =*/
@@ -1660,7 +1692,7 @@ optionProcess( pOpts, argCt, argVect )
     return pOpts->origArgCt;
 
  optionsDone:
-    
+
     /*
      *  IF    there were no errors
      *    AND we have RC/INI files
@@ -1672,7 +1704,7 @@ optionProcess( pOpts, argCt, argVect )
         tOptDesc*  pOD = pOpts->pOptDesc + pOpts->specOptIdx.save_opts;
 
         if (SELECTED_OPT( pOD )) {
-            optionSave( pOpts );
+            optionSaveFile( pOpts );
             exit( EXIT_SUCCESS );
         }
     }
